/*
 * HdrCalctor_RGB_U8.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
  @file  HdrCalctor_RGB_U8.hpp

  Hdr-Calctor for `PackImgScheme2D's.
  
  Kein Ctor fuer `ImgVector'-Argument anbieten, denn das hiesse, die Packs hier
   zu kreieren, doch in diese Kreation sollen ja noch eventuelle Verschiebungs-
   korrekturen einfliessen. Deshalb dies extern abhandeln. Ctor(en) also nur fuer
   fertige Pack's! 
*/
#ifndef HdrCalctor_RGB_U8_hpp
#define HdrCalctor_RGB_U8_hpp

#include "br_types.hpp"             // typedef uint8
#include "br_PackImgScheme2D.hpp"
#include "HdrCalctorBase.hpp"
#include "FollowUpValues_RGB_U8.hpp"
#include "WeightFunc.hpp"
#include "ProgressInfo.hpp"
#include "br_macros.hpp"            // DTOR()



namespace br {

using namespace TNT;

/**===========================================================================
 
  @class  HdrCalctor_RGB_U8
  
  Leistungen: 
 
  ACHTUNG: Calctor hat fuer Fortleben des Packs selbst zu sorgen, also Kopie 
   ziehen, nicht nur Referenz nehmen!
 
*============================================================================*/
class HdrCalctor_RGB_U8 : public HdrCalctorBase
{
public:

    /**
    *   Type of the Pack we work up
    */    
    typedef PackImgScheme2D_RGB_U8   Pack;


private:

    //  The Pack given in the Ctor; copy!
    Pack  pack_;                          // object, no ref!

    //  Our instance to calculate follow-up values
    FollowUpValues_RGB_U8  followUp_;

    //  Ptr to our weight function object for response computation and merging
    WeightFunc_U8*  pWeight_;

    //  Maximal possible z-value
    static const uint8  z_max_ = 255;

      
public:
     
    //  Ctor... (`const Pack &' - we take a copy)
    HdrCalctor_RGB_U8 (const Pack &, WeightFunc_U8*, ProgressInfo* = NULL);

    //  Dtor...
    ~HdrCalctor_RGB_U8()                {DTOR("");}


    //==================================================================
    //  The abstract interface of HdrCalctorBase we have to implement...
    //==================================================================
    
    unsigned n_zvals() const            {return 256;}
    //unsigned z_max() const            {return 255;}     // Unused
    
    const br::PackBase & packBase() const              {return pack_;}
          br::PackBase & packBase()                    {return pack_;}
    
    const br::FollowUpValuesBase & fllwUpVals() const  {return followUp_;}
          br::FollowUpValuesBase & fllwUpVals()        {return followUp_;}


    //==================
    //  FolloUpValues...
    
    //  Compute always
    void compute_FollowUpValues();
    void compute_FollowUpValues (int channel)   {compute_FollowUpValues();} 

    //  Compute only, if `refpic' has been changed since last computation
    void update_FollowUpValues();
    void update_FollowUpValues (int channel)    {update_FollowUpValues();} 

      
    //==================== 
    //  Response curves...  
      
    //  Compute the response curves
    void compute_Response();
    void compute_Response (int channel)         {compute_Response();}


    //============================
    //  Assembling an HDR image...

    /*  Merge an HDR image  -  pure merging using the current response curves!
     *   @return Null-Image, if none.
     */
    ImageHDR merge_HDR();
    ImageHDR merge_LogHDR();

    /*  Complete an HDR image creation
     *   If response curves exist, merge only, else compute them before.
     */
    ImageHDR complete_HDR();

    //===============================================//
    //  ...End of abstract HdrCalctorBase interface  //
    //===============================================//

    //  Get and set the pointer to the weight function object
    const WeightFunc_U8* weightFuncPtr()  const         {return pWeight_;}
    void setWeightFuncPtr (WeightFunc_U8* p)            {pWeight_ = p; /*assert(p);*/}

};


}  // namespace

#endif // HdrCalctor_RGB_U8_hpp

// END OF FILE
