/*
 * StopValueChoicer.cpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
   @file  StopValueChoicer.cpp
*/   

#include "StopValueChoicer.hpp"


static const char* tooltip_stop_ = 
//"Hier koennen Sie Belichtungszeiten generieren, die mit einem festen Faktor F=2^(stop) wachsen. Traditionell wird dabei nicht F, sondern der 2er-Exponent \"stop\", der den Differenzen der Blendenzahlen entspricht, angegeben. Bsp: stop=1 --> F=2, stop=2 --> F=4.";
"Here you can generate exposure times increasing by a constant factor F=2^(stop). F is stated traditionally by specifying the exponent \"stop\", which corresponds to the differences of aperture values.";


/**
*   Ctor:  
*  
*   FLUID haengt umgewidmeten "Class"en nach dem Ctor standardmaessig einen
*    Codeblock an, der u.a. when() und align() setzt, so dass die default
*    Setzungen hier ueberschrieben werden. Sie sind in Fluid haendisch neu zu 
*    setzen!
*/
StopValueChoicerLocal::StopValueChoicerLocal 
                         (int X, int Y, int W, int H, const char* la)
  : Fl_Choice(X,Y,W,H,la)
{
    menu (menu_);
    value (3);                // stop = "1" as default
    callback ((Fl_Callback*)cb_fltk_, this);
    when (FL_WHEN_RELEASE_ALWAYS); 
    align (FL_ALIGN_LEFT);
    tooltip (tooltip_stop_);
}


void StopValueChoicerLocal::cb_fltk_i (Fl_Menu_* w) 
{
    if (!pBr2Hdr) return;  // not initalized
    
    //  Generate new times accordingly to the menu 'stop' value
    //   (sets also pBr2Hdr->stopvalue!)
    pBr2Hdr -> set_TimesByStop (menuMap_[ w->value() ].value);
}


// static elements...

StopValueChoicerLocal::MenuMapEntry  StopValueChoicerLocal::menuMap_[] = {
    {"0.33...", 1./3.   }, 
    {"0.5"    , 0.5     },
    {"0.66...", 2./3.   },
    {"1"      , 1.      },
    {"1.33...", 1.+1./3.},
    {"1.5"    , 1.5     },
    {"1.66...", 1.+2./3.},
    {"2"      , 2.      }
};  
Fl_Menu_Item  StopValueChoicerLocal::menu_[] = {
    {menuMap_[0].text},
    {menuMap_[1].text},
    {menuMap_[2].text},
    {menuMap_[3].text},
    {menuMap_[4].text},
    {menuMap_[5].text},
    {menuMap_[6].text},
    {menuMap_[7].text},
    {0}
};


// END OF FILE
