/*
 * StopValueChoicer.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
  @file StopValueChoicer.hpp
   
  Contents:
   - StopValueChoicerLocal
   - StopValueChoicer

  Beispiel einer lokal->global-Hierarchie, bei der der allgemeine (=lokale)
   Fall mittels Zeiger und init_DataRef() inplementiert ist (arbeiten muss),
   und die globale Variante durch Spezialisierung gewonnen wird. Sonst hatte
   ich nur die globale Variante, die dann gleich mit einer Referenz arbeiten
   kann und ohne init_DataRef() auskommt.
*/   
#ifndef StopValueChoicer_hpp
#define StopValueChoicer_hpp


#include <FL/Fl_Choice.H>
#include "../core/Br2HdrManager.hpp"
#include "../core/Br2Hdr.hpp"


/**==================================================================
* 
*   @class  StopValueChoicerLocal
* 
*   Choice-Menu for the 'stop value' with Fl_Widget Ctor, so that usable in
*    Fluid. Es ist dies mal das Beispiel einer "lokalen" Variante (mehrere 
*    Br2HdrManager-Instanzen moegl.), bei der Referenz des Managers nach der
*    Widget-Konstruktion in Fluids "Extra Code" per init_DataRef() mitzuteilen 
*    waere.
* 
*   `StopValueChoicer' unten ist die globale Variante, die auf das singulaere
*    Objekt `Br2Hdr::Instance()' referenziert.
* 
*   Falls 'stop'-Aenderungen auch an solchem Widget vorbei moeglich sind, z.B.
*    mehrere StopValueChoicer im Programm, muesste der Event-Verkehr mitgeschnitten
*    werden (Ableiten noch von EventReceiver), um die Anzeige aktuell zu halten.
*    Dazu braeuchte es dann allerdings eines ebenfalls *lokalen* `EventReceiver's,
*    der bisher nur global vorliegt.
* 
*====================================================================*/
class StopValueChoicerLocal : public Fl_Choice 
{ 
    struct MenuMapEntry {const char* text; float value;};
    
    static MenuMapEntry  menuMap_[];
    static Fl_Menu_Item  menu_[];
    
    br::Br2HdrManager *  pBr2Hdr;   // the manager instance we refer to

public:
    StopValueChoicerLocal (int X, int Y, int W, int H, const char* la=0);
    
    void init_DataRef (br::Br2HdrManager* p)    {pBr2Hdr = p;}
    void init_DataRef (br::Br2HdrManager& m)    {pBr2Hdr = &m;}

private:
    void        cb_fltk_i(Fl_Menu_*);
    static void cb_fltk_ (Fl_Menu_* w, StopValueChoicerLocal* I)  
      {I -> cb_fltk_i( w );}
};      


/**==================================================================
* 
*   @class  StopValueChoicer
* 
*   Choice-Menu for the 'Stop'-Value with Fl_Widget Ctor, so that usable in
*    Fluid. Globale Variante: Initialisiert sich im Ctor automatisch fuer
*    das singulaere Objekt `Br2Hdr::Instance()', so dass kein init_DataRef() 
*    noetig. init_DataRef() sollte strenggenommen noch privat gemacht (verdeckt)
*    werden, da oeffentlich damit allenfalls noch Schaden angerichtet werden
*    koennte.
* 
*====================================================================*/
class StopValueChoicer : public StopValueChoicerLocal 
{ 
public:
    StopValueChoicer (int X, int Y, int W, int H, const char* la=0)
      : StopValueChoicerLocal(X,Y,W,H,la) 
      { init_DataRef( br::Br2Hdr::Instance() ); }
};      



#endif  // StopValueChoicer_hpp

// END OF FILE
